==> spip_4.0.4.orig.tar.xz: plugins-dist/bigup/lang/bigup_fr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans https://git.spip.net/spip/bigup.git
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bigup_titre' => 'Big Upload',
	'bouton_annuler' => 'Annuler',
	'bouton_enlever' => 'Enlever',

	// C
	'cfg_charger_public' => 'Script dans l’espace public',
	'cfg_charger_public_case' => 'Charger les scripts dans l’espace public',
	'cfg_max_file_size' => 'Taille maximum des fichiers',
	'cfg_max_file_size_explication' => 'Taille maximum des fichiers (en Mb).',
	'cfg_titre_parametrages' => 'Paramétrages de Big Upload',
	'choisir' => 'Choisir',

	// D
	'deposer_la_vignette_ici' => 'Déposer la vignette ici',
	'deposer_le_logo_ici' => 'Déposer le LOGO ici',
	'deposer_vos_fichiers_ici' => 'Déposer vos fichiers ici',
	'deposer_votre_fichier_ici' => 'Déposer votre fichier ici',

	// E
	'erreur_de_transfert' => 'Erreur de transfert.',
	'erreur_probleme_survenu' => 'Un problème est survenu…',
	'erreur_taille_max' => 'Le fichier ne doit pas dépasser @taille@',
	'erreur_type_fichier' => 'Type de fichier incorrect !',

	// F
	'fichier_efface' => 'Fichier effacé',

	// O
	'ou' => 'ou',

	// S
	'selectionner' => 'Sélectionner',
	'succes_fichier_envoye' => 'Le fichier a été envoyé',
	'succes_logo_envoye' => 'Le logo a été envoyé',
	'succes_vignette_envoyee' => 'La vignette a été envoyée',

	// T
	'televerser' => 'Téléverser',
	'titre_page_configurer_bigup' => 'Configurer Big Upload',

	// Z
	'zbug_necessite_plugin' => 'La balise <code>@balise@</code> nécessite le plugin <code>@plugin@</code>'
);

==> spip_4.1.9+dfsg.orig.tar.xz: plugins-dist/bigup/lang/bigup_fr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans https://git.spip.net/spip/bigup.git
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bigup_titre' => 'Big Upload',
	'bouton_annuler' => 'Annuler',
	'bouton_enlever' => 'Enlever',

	// C
	'cfg_charger_public' => 'Script dans l’espace public',
	'cfg_charger_public_case' => 'Charger les scripts dans l’espace public',
	'cfg_explication_parametrages' => 'Ces options ne concernent que les champs de fichiers gérés par un bloc de glisser-déposer.',
	'cfg_max_file_size' => 'Taille maximum des fichiers',
	'cfg_max_file_size_explication' => 'Taille maximum des fichiers (en Mb).',
	'cfg_titre_parametrages' => 'Téléversement des fichiers',
	'choisir' => 'Choisir',

	// D
	'deposer_la_vignette_ici' => 'Déposer la vignette ici',
	'deposer_le_logo_ici' => 'Déposer le LOGO ici',
	'deposer_vos_fichiers_ici' => 'Déposer vos fichiers ici',
	'deposer_votre_fichier_ici' => 'Déposer votre fichier ici',

	// E
	'erreur_de_transfert' => 'Erreur de transfert.',
	'erreur_probleme_survenu' => 'Un problème est survenu…',
	'erreur_taille_max' => 'Le fichier ne doit pas dépasser @taille@',
	'erreur_type_fichier' => 'Type de fichier incorrect !',

	// F
	'fichier_efface' => 'Fichier effacé',

	// O
	'ou' => 'ou',

	// S
	'selectionner' => 'Sélectionner',
	'succes_fichier_envoye' => 'Le fichier a été envoyé',
	'succes_logo_envoye' => 'Le logo a été envoyé',
	'succes_vignette_envoyee' => 'La vignette a été envoyée',

	// T
	'televerser' => 'Téléverser',
	'titre_page_configurer_bigup' => 'Configurer Big Upload',

	// Z
	'zbug_necessite_plugin' => 'La balise <code>@balise@</code> nécessite le plugin <code>@plugin@</code>'
);
